==> react-native-digitcamera-1.38.0.tgz: package/src/Screens/DemoVideo.js <==
import React, { useEffect, useMemo, useRef, useState } from "react";
import {
  BackHandler,
  SafeAreaView,
  StatusBar,
  StyleSheet,
  View,
  TouchableOpacity,
  Alert,
  Text,
  Platform,
  Animated,
} from "react-native";
const iOS = Platform.OS === "ios";
import { Spinner } from "react-native-digitcamera/src/common/ThemedComponents";
import Colors from "react-native-digitcamera/src/common/Colors";
import MCIcon from "react-native-vector-icons/MaterialCommunityIcons";
import Database from "../../../../Components/common/DAsyncStorage";
import NetInfo from "@react-native-community/netinfo";
import { useIsFocused } from "@react-navigation/native";

import {
  SCREEN_HEIGHT,
  SCREEN_WIDTH,
} from "react-native-digitcamera/src/common/Constants";
import VideoPlayer from "react-native-video-player";
import { PrimaryButton } from "../../../../Components/common/ThemedComponents";
import {
  UELogEvent,
  UELogMessage,
} from "../common/libEventLog/UserExperior/LibUserExperior";
import { checkInternetSpeed } from "react-native-digitcamera/src/Screens/OfflineFlow/CommonFunc";
import { CreateActivityId } from "react-native-digitcamera/src/Screens/OfflineFlow/CreateActivityId";
import { useDispatch, useSelector } from "react-redux";

var isFocused;
const DemoVideo = ({ navigation, route }) => {
  /* 
  Animating this screen to make the navigation animation more smooth
   */
  const animatedOpacity = useRef(new Animated.Value(1)).current;

  const fadeInAnimation = Animated.timing(animatedOpacity, {
    toValue: 1,
    duration: 500,
    useNativeDriver: true,
  });

  // useEffect(() => {
  //   setTimeout(() => {
  //     fadeInAnimation.start();
  //   }, 200);
  // }, []);

  const { videoUri, OnSkip, OnProceed, withoutRCB } = route.params;
  const [actionVisibility, setActionVisibility] = useState(true);
  const [showSkipOption, setShowSkipOption] = useState(false);
  const [startInspection, setStartInspection] = useState(false);
  const [isNetworkAvailable, setIsNetworkAvailable] = useState(true);
  const [isBuffering, setIsBuffering] = useState(false);

  var videoRef = useRef();
  const dispatch = useDispatch();
  isFocused = useIsFocused();

  const shouldEnableProceed = useRef(false);

  const network = useSelector((state) => state.network);
  const { isInternetReachable } = network;

  // useEffect(() => {
  //   setIsNetworkAvailable(isInternetReachable);
  //   if (isInternetReachable === false) navigation.navigate("QuickTips");
  // }, [network]);

  useEffect(() => {
    checkForSkip();

    console.log("**** DemoVideo useEffect: videoUri: " + videoUri);
    let Immersive = undefined;
    let restoreImmersive = undefined;
    if (!iOS) {
      Immersive = require("react-native-immersive").Immersive;
      Immersive.setImmersive(true);
      restoreImmersive = () => {
        __DEV__ && console.log("Immersive state changed!");
        Immersive.setImmersive(true);
      };
      Immersive.addImmersiveListener(restoreImmersive);
    }

    // disabled back handler
    const backHandler = BackHandler.addEventListener(
      "hardwareBackPress",
      () => {
        return true;
      }
    );

    return () => {
      if (Immersive !== undefined) {
        // Immersive.off();
        Immersive.removeImmersiveListener(restoreImmersive);
      }
      backHandler.remove();
    };
  }, []);

  const startInspectionView = () => {
    return (
      <View style={styles.startRecordingView}>
        {console.log("@@@@@@@@@", startInspection)}
        <View style={styles.startRecordingSubView}>
          <Text style={styles.textTitle}>{"You're ready!"}</Text>
          <View
            style={{ flexDirection: "row", justifyContent: "space-evenly" }}
          >
            <PrimaryButton
              onPress={() => {
                setStartInspection(false);
                setActionVisibility(false);
                if (videoRef) {
                  videoRef.resume();
                }
              }}
              mode={"outlined"}
            >
              Replay Demo
            </PrimaryButton>
            <PrimaryButton
              style={styles.startRecordingButton}
              onPress={() => {
                navigation.navigate("QuickTips");
              }}
            >
              {"Let’s start"}
            </PrimaryButton>
          </View>
        </View>
      </View>
    );
  };

  const checkForSkip = async () => {
    var PIDemoVideoViewStaus = await Database.get("PIDemoVideoViewStaus");
    var AppLoginStatus = await Database.get("AppLoginStatus");

    console.log(
      "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!",
      PIDemoVideoViewStaus?.isVideoSeen,
      AppLoginStatus.userType
    );
    UELogEvent("DemoVideo, checkForSkip", {
      PIDemoVideoViewStatus: JSON.stringify(PIDemoVideoViewStaus?.isVideoSeen),
      AppLoginStatus: JSON.stringify(AppLoginStatus?.userType),
    });
    if (
      __DEV__ ||
      (PIDemoVideoViewStaus?.isVideoSeen == true &&
        AppLoginStatus.userType === "DealerOrAgent")
    ) {
      // show skip
      setShowSkipOption(true);
      console.log("*** DemoVideo skip option shown");
    } else if (PIDemoVideoViewStaus?.isVideoSeen == undefined) {
      setShowSkipOption(false);
      console.log("*** DemoVideo skip option removed");
    }
  };

  // useEffect(() => {
  //   if (!isNetworkAvailable) {

  //   }
  // }, [])

  if (!isNetworkAvailable) {
    return <View style={{ flex: 1, backgroundColor: "black" }} />;
  }

  const onVideoStart = () => {
    // Let user spend 30 sec in Demo Video Screen
    setTimeout(() => {
      shouldEnableProceed.current = true;
    }, 30000);
  };

  return (
    <SafeAreaView
      edges={iOS ? ["top", "bottom", "right"] : []}
      style={styles.safeArea}
    >
      <Animated.View
        style={[
          styles.main,
          {
            opacity: animatedOpacity,
          },
        ]}
      >
        <Spinner loading={isBuffering} />
        <StatusBar hidden={true} />
        <VideoPlayer
          ref={(p) => (videoRef = p)}
          video={{
            uri:
              "https://d2h44aw7l5xdvz.cloudfront.net/CRM/PRM/PI_Demo_Cut.m4v",
            cache: true,
          }}
          videoHeight={SCREEN_HEIGHT}
          videoWidth={SCREEN_WIDTH}
          playInBackground={false}
          pauseOnPress={true}
          autoplay={true}
          bufferConfig={
            iOS
              ? {}
              : {
                  minBufferMs: 5000,
                  maxBufferMs: 15000,
                  bufferForPlaybackMs: 2500,
                  bufferForPlaybackAfterRebufferMs: 5000,
                }
          }
          onBuffer={(bufferData) => {
            console.log("fsdlnfsdkfndkf", bufferData);
            if (bufferData.isBuffering) {
              //only show buffer loading, when user has pressed watch demo
              if (!actionVisibility) {
                // setIsBuffering(true);
              }
            } else {
              // setIsBuffering(false);
            }
          }}
          onLoad={() => {
            const timer = setTimeout(() => {
              clearTimeout(timer);
              if (videoRef) {
                videoRef.pause();
              }
            }, 0);
          }}
          disableSeek={false}
          style={styles.productImageStyle}
          onEnd={() => {
            const update = async () => {
              await Database.update("PIDemoVideoViewStaus", {
                isVideoSeen: true,
              });
            };
            update();
            if (shouldEnableProceed.current) {
              setStartInspection(true);
            }
            // check for skip option
            checkForSkip();
          }}
        />

        {/* demo playing screen */}
        {!actionVisibility && (
          <View style={[styles.skipView]}>
            <TouchableOpacity
              style={{
                // flex: 1,
                flexDirection: "row",
                justifyContent: "space-between",
              }}
              onPress={() => {
                if (Platform.OS === "android") {
                  navigation.navigate("WithQuote");
                  // if (withoutRCB) {

                  //   Orientation.lockToPortrait();
                  // } else if (navigation.canGoBack()) {
                  //   navigation.pop();
                  // }
                }
              }}
            >
              <MCIcon
                name="arrow-bottom-left"
                size={24}
                color="white"
                style={{ transform: [{ rotate: "45deg" }], marginRight: 8 }}
              />
              <Text style={styles.demoVideoText}>{""}</Text>
            </TouchableOpacity>
            <TouchableOpacity
              style={{}}
              onPress={() => {
                /* @STARTRECORDING */
                if (showSkipOption) {
                  setStartInspection(true);
                }
              }}
            >
              {showSkipOption ? (
                <Text style={styles.proceedText}>{"Skip >>"}</Text>
              ) : (
                <Text style={styles.proceedText}>
                  {"Please watch full video to proceed"}
                </Text>
              )}
            </TouchableOpacity>
          </View>
        )}

        {/* pop-up screen */}
        {actionVisibility && (
          <View style={[styles.payView]}>
            <TouchableOpacity
              style={{
                justifyContent: "flex-start",
                alignItems: "center",
                flexDirection: "row",
                position: "absolute",
                left: 1,
                top: 1,
                padding: 16,
              }}
              onPress={() => {
                if (Platform.OS === "android") {
                  navigation.navigate("WithQuote");
                }
              }}
            >
              <MCIcon
                name="arrow-bottom-left"
                size={24}
                color="black"
                style={{ transform: [{ rotate: "45deg" }], marginTop: 4 }}
              />
            </TouchableOpacity>
            <TouchableOpacity
              style={{ justifyContent: "center", alignItems: "center" }}
              onPress={() => {
                setActionVisibility(false);
                if (videoRef) {
                  // setIsBuffering(true);
                  videoRef.resume();
                  // start the timer
                  onVideoStart();
                }
              }}
            >
              <MCIcon
                name="play-circle"
                size={48}
                color={Colors.digitYellow}
                style={{ backgroundColor: "transparent" }}
              />
              <Text style={styles.playVideoText}>{"Watch Demo Video"}</Text>
              <Text style={styles.infoText}>
                {"Please watch full video to proceed"}
              </Text>
            </TouchableOpacity>

            {/* Skip button on paused screen */}
            <TouchableOpacity
              style={{
                position: "absolute",
                right: 1,
                bottom: 1,
                padding: 18,
              }}
              onPress={() => {
                if (showSkipOption) {
                  setStartInspection(true);
                }
              }}
            >
              {showSkipOption ? (
                <Text style={styles.proceedText}>{"Skip >>"}</Text>
              ) : null}
            </TouchableOpacity>
          </View>
        )}
        {startInspection && startInspectionView()}
      </Animated.View>
    </SafeAreaView>
  );
};
const styles = StyleSheet.create({
  safeArea: {
    flex: 1,
    backgroundColor: Colors.darkBlack,
  },
  main: {
    flex: 1,
    justifyContent: "flex-start",
  },
  productImageStyle: {
    height: "100%",
    width: "100%",
  },
  skipView: {
    position: "absolute",
    width: "100%",
    flexDirection: "row",
    justifyContent: "space-between",
    alignItems: "center",
    backgroundColor: "transparent",
    padding: 16,
  },
  payView: {
    position: "absolute",
    width: "100%",
    flexDirection: "column",
    height: "100%",
    justifyContent: "center",
    backgroundColor: "rgba(0, 0, 0, 0.8)",
  },
  demoVideoText: {
    backgroundColor: "transparent",
    fontFamily: "Muli-Bold",
    fontSize: 18,
    // padding: 20,
    color: "white",
  },
  playVideoText: {
    backgroundColor: "transparent",
    fontFamily: "Muli-Bold",
    fontSize: 18,
    padding: 20,
    alignSelf: "center",
    color: "white",
  },
  proceedText: {
    backgroundColor: "transparent",
    fontFamily: "Muli-Regular",
    fontSize: 13,
    alignSelf: "flex-end",
    color: "white",
    paddingRight: 23,
  },
  infoText: {
    backgroundColor: "transparent",
    fontFamily: "Muli-Regular",
    fontSize: 13,
    alignSelf: "center",
    color: "white",
  },
  startRecordingView: {
    position: "absolute",
    zIndex: 400,
    width: "100%",
    height: "80%",
    top: "10%",
    justifyContent: "center",
  },
  startRecordingSubView: {
    width: "40%",
    height: "50%",
    alignSelf: "center",
    borderRadius: 10,
    justifyContent: "space-evenly",
    backgroundColor: "#FFFFFF",
    paddingHorizontal: 16,
    elevation: 4,
  },
  textTitle: {
    color: "#000000",
    fontSize: 18,
    fontFamily: "Muli-Regular",
    alignSelf: "center",
    // paddingBottom: 24,
  },
  // startRecordingButton: {
  //   width: "70%",
  //   height: "10%",
  //   alignSelf: "center",
  // },
});
export default DemoVideo;

==> react-native-digitcamera-1.40.0.tgz: package/src/Screens/DemoVideo.js <==
import React, { useEffect, useMemo, useRef, useState } from "react";
import {
  BackHandler,
  SafeAreaView,
  StatusBar,
  StyleSheet,
  View,
  TouchableOpacity,
  Alert,
  Text,
  Platform,
  Animated,
} from "react-native";
const iOS = Platform.OS === "ios";
import { Spinner } from "react-native-digitcamera/src/common/ThemedComponents";
import Colors from "react-native-digitcamera/src/common/Colors";
import MCIcon from "react-native-vector-icons/MaterialCommunityIcons";
import Database from "../../../../Components/common/DAsyncStorage";
import NetInfo from "@react-native-community/netinfo";
import { useIsFocused } from "@react-navigation/native";

import {
  SCREEN_HEIGHT,
  SCREEN_WIDTH,
} from "react-native-digitcamera/src/common/Constants";
import VideoPlayer from "react-native-video-player";
import { PrimaryButton } from "../../../../Components/common/ThemedComponents";
import {
  UELogEvent,
  UELogMessage,
} from "../common/libEventLog/UserExperior/LibUserExperior";
import { checkInternetSpeed } from "react-native-digitcamera/src/Screens/OfflineFlow/CommonFunc";
import { CreateActivityId } from "react-native-digitcamera/src/Screens/OfflineFlow/CreateActivityId";
import { useDispatch, useSelector } from "react-redux";

var isFocused;
const DemoVideo = ({ navigation, route }) => {
  /* 
  Animating this screen to make the navigation animation more smooth
   */
  const animatedOpacity = useRef(new Animated.Value(1)).current;

  const fadeInAnimation = Animated.timing(animatedOpacity, {
    toValue: 1,
    duration: 500,
    useNativeDriver: true,
  });

  // useEffect(() => {
  //   setTimeout(() => {
  //     fadeInAnimation.start();
  //   }, 200);
  // }, []);

  const { videoUri, OnSkip, OnProceed, withoutRCB } = route.params;
  const [actionVisibility, setActionVisibility] = useState(true);
  const [showSkipOption, setShowSkipOption] = useState(false);
  const [startInspection, setStartInspection] = useState(false);
  const [isNetworkAvailable, setIsNetworkAvailable] = useState(true);
  const [isBuffering, setIsBuffering] = useState(false);

  var videoRef = useRef();
  const dispatch = useDispatch();
  isFocused = useIsFocused();

  const shouldEnableProceed = useRef(false);

  const network = useSelector((state) => state.network);
  const { isInternetReachable } = network;

  // useEffect(() => {
  //   setIsNetworkAvailable(isInternetReachable);
  //   if (isInternetReachable === false) navigation.navigate("QuickTips");
  // }, [network]);

  useEffect(() => {
    checkForSkip();

    console.log("**** DemoVideo useEffect: videoUri: " + videoUri);
    let Immersive = undefined;
    let restoreImmersive = undefined;
    if (!iOS) {
      Immersive = require("react-native-immersive").Immersive;
      Immersive.setImmersive(true);
      restoreImmersive = () => {
        __DEV__ && console.log("Immersive state changed!");
        Immersive.setImmersive(true);
      };
      Immersive.addImmersiveListener(restoreImmersive);
    }

    // disabled back handler
    const backHandler = BackHandler.addEventListener(
      "hardwareBackPress",
      () => {
        return true;
      }
    );

    return () => {
      if (Immersive !== undefined) {
        // Immersive.off();
        Immersive.removeImmersiveListener(restoreImmersive);
      }
      backHandler.remove();
    };
  }, []);

  const startInspectionView = () => {
    return (
      <View style={styles.startRecordingView}>
        {console.log("@@@@@@@@@", startInspection)}
        <View style={styles.startRecordingSubView}>
          <Text style={styles.textTitle}>{"You're ready!"}</Text>
          <View
            style={{ flexDirection: "row", justifyContent: "space-evenly" }}
          >
            <PrimaryButton
              onPress={() => {
                setStartInspection(false);
                setActionVisibility(false);
                if (videoRef) {
                  videoRef.resume();
                }
              }}
              mode={"outlined"}
            >
              Replay Demo
            </PrimaryButton>
            <PrimaryButton
              style={styles.startRecordingButton}
              onPress={() => {
                navigation.navigate("QuickTips");
              }}
            >
              {"Let’s start"}
            </PrimaryButton>
          </View>
        </View>
      </View>
    );
  };

  const checkForSkip = async () => {
    var PIDemoVideoViewStaus = await Database.get("PIDemoVideoViewStaus");
    var AppLoginStatus = await Database.get("AppLoginStatus");

    console.log(
      "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!",
      PIDemoVideoViewStaus?.isVideoSeen,
      AppLoginStatus.userType
    );
    UELogEvent("DemoVideo, checkForSkip", {
      PIDemoVideoViewStatus: JSON.stringify(PIDemoVideoViewStaus?.isVideoSeen),
      AppLoginStatus: JSON.stringify(AppLoginStatus?.userType),
    });
    if (
      __DEV__ ||
      (PIDemoVideoViewStaus?.isVideoSeen == true &&
        AppLoginStatus.userType === "DealerOrAgent")
    ) {
      // show skip
      setShowSkipOption(true);
      console.log("*** DemoVideo skip option shown");
    } else if (PIDemoVideoViewStaus?.isVideoSeen == undefined) {
      setShowSkipOption(false);
      console.log("*** DemoVideo skip option removed");
    }
  };

  // useEffect(() => {
  //   if (!isNetworkAvailable) {

  //   }
  // }, [])

  if (!isNetworkAvailable) {
    return <View style={{ flex: 1, backgroundColor: "black" }} />;
  }

  const onVideoStart = () => {
    // Let user spend 30 sec in Demo Video Screen
    setTimeout(() => {
      shouldEnableProceed.current = true;
    }, 30000);
  };

  return (
    <SafeAreaView
      edges={iOS ? ["top", "bottom", "right"] : []}
      style={styles.safeArea}
    >
      <Animated.View
        style={[
          styles.main,
          {
            opacity: animatedOpacity,
          },
        ]}
      >
        <Spinner loading={isBuffering} />
        <StatusBar hidden={true} />
        <VideoPlayer
          ref={(p) => (videoRef = p)}
          video={{
            uri: "https://d2h44aw7l5xdvz.cloudfront.net/CRM/PRM/PI_Demo_Cut.m4v",
            cache: true,
          }}
          videoHeight={SCREEN_HEIGHT}
          videoWidth={SCREEN_WIDTH}
          playInBackground={false}
          pauseOnPress={true}
          autoplay={true}
          bufferConfig={
            iOS
              ? {}
              : {
                  minBufferMs: 5000,
                  maxBufferMs: 15000,
                  bufferForPlaybackMs: 2500,
                  bufferForPlaybackAfterRebufferMs: 5000,
                }
          }
          onBuffer={(bufferData) => {
            console.log("fsdlnfsdkfndkf", bufferData);
            if (bufferData.isBuffering) {
              //only show buffer loading, when user has pressed watch demo
              if (!actionVisibility) {
                // setIsBuffering(true);
              }
            } else {
              // setIsBuffering(false);
            }
          }}
          onLoad={() => {
            const timer = setTimeout(() => {
              clearTimeout(timer);
              if (videoRef) {
                videoRef.pause();
              }
            }, 0);
          }}
          disableSeek={false}
          style={styles.productImageStyle}
          onEnd={() => {
            const update = async () => {
              await Database.update("PIDemoVideoViewStaus", {
                isVideoSeen: true,
              });
            };
            update();
            if (shouldEnableProceed.current) {
              setStartInspection(true);
            }
            // check for skip option
            checkForSkip();
          }}
          customStyles={{
            seekBarKnob: {
              backgroundColor: Colors.digitYellow,
              elevation: 2,
              height: 30,
              width: 30,
              borderRadius: 30,
            },
            seekBarProgress: {
              backgroundColor: "white",
            },
            seekBarBackground: {
              backgroundColor: "#5F5B5B",
            },
          }}
        />

        {/* demo playing screen */}
        {!actionVisibility && (
          <View style={[styles.skipView]}>
            <TouchableOpacity
              style={{
                // flex: 1,
                flexDirection: "row",
                justifyContent: "space-between",
              }}
              onPress={() => {
                if (Platform.OS === "android") {
                  navigation.navigate("WithQuote");
                  // if (withoutRCB) {

                  //   Orientation.lockToPortrait();
                  // } else if (navigation.canGoBack()) {
                  //   navigation.pop();
                  // }
                }
              }}
            >
              <MCIcon
                name="arrow-bottom-left"
                size={24}
                color="white"
                style={{ transform: [{ rotate: "45deg" }], marginRight: 8 }}
              />
              <Text style={styles.demoVideoText}>{""}</Text>
            </TouchableOpacity>
            <TouchableOpacity
              style={{}}
              onPress={() => {
                /* @STARTRECORDING */
                if (showSkipOption) {
                  setStartInspection(true);
                }
              }}
            >
              {showSkipOption ? (
                <Text style={styles.proceedText}>{"Skip >>"}</Text>
              ) : (
                <Text style={styles.proceedText}>
                  {"Please watch full video to proceed"}
                </Text>
              )}
            </TouchableOpacity>
          </View>
        )}

        {/* pop-up screen */}
        {actionVisibility && (
          <View style={[styles.payView]}>
            <TouchableOpacity
              style={{
                justifyContent: "flex-start",
                alignItems: "center",
                flexDirection: "row",
                position: "absolute",
                left: 1,
                top: 1,
                padding: 16,
              }}
              onPress={() => {
                if (Platform.OS === "android") {
                  navigation.navigate("WithQuote");
                }
              }}
            >
              <MCIcon
                name="arrow-bottom-left"
                size={24}
                color="black"
                style={{ transform: [{ rotate: "45deg" }], marginTop: 4 }}
              />
            </TouchableOpacity>
            <TouchableOpacity
              style={{ justifyContent: "center", alignItems: "center" }}
              onPress={() => {
                setActionVisibility(false);
                if (videoRef) {
                  // setIsBuffering(true);
                  videoRef.resume();
                  // start the timer
                  onVideoStart();
                }
              }}
            >
              <MCIcon
                name="play-circle"
                size={48}
                color={Colors.digitYellow}
                style={{ backgroundColor: "transparent" }}
              />
              <Text style={styles.playVideoText}>{"Watch Demo Video"}</Text>
              <Text style={styles.infoText}>
                {"Please watch full video to proceed"}
              </Text>
            </TouchableOpacity>

            {/* Skip button on paused screen */}
            <TouchableOpacity
              style={{
                position: "absolute",
                right: 1,
                bottom: 1,
                padding: 18,
              }}
              onPress={() => {
                if (showSkipOption) {
                  setStartInspection(true);
                }
              }}
            >
              {showSkipOption ? (
                <Text style={styles.proceedText}>{"Skip >>"}</Text>
              ) : null}
            </TouchableOpacity>
          </View>
        )}
        {startInspection && startInspectionView()}
      </Animated.View>
    </SafeAreaView>
  );
};
const styles = StyleSheet.create({
  safeArea: {
    flex: 1,
    backgroundColor: Colors.darkBlack,
  },
  main: {
    flex: 1,
    justifyContent: "flex-start",
  },
  productImageStyle: {
    height: "100%",
    width: "100%",
  },
  skipView: {
    position: "absolute",
    width: "100%",
    flexDirection: "row",
    justifyContent: "space-between",
    alignItems: "center",
    backgroundColor: "transparent",
    padding: 16,
  },
  payView: {
    position: "absolute",
    width: "100%",
    flexDirection: "column",
    height: "100%",
    justifyContent: "center",
    backgroundColor: "rgba(0, 0, 0, 0.8)",
  },
  demoVideoText: {
    backgroundColor: "transparent",
    fontFamily: "Muli-Bold",
    fontSize: 18,
    // padding: 20,
    color: "white",
  },
  playVideoText: {
    backgroundColor: "transparent",
    fontFamily: "Muli-Bold",
    fontSize: 18,
    padding: 20,
    alignSelf: "center",
    color: "white",
  },
  proceedText: {
    backgroundColor: "transparent",
    fontFamily: "Muli-Regular",
    fontSize: 13,
    alignSelf: "flex-end",
    color: "white",
    paddingRight: 23,
  },
  infoText: {
    backgroundColor: "transparent",
    fontFamily: "Muli-Regular",
    fontSize: 13,
    alignSelf: "center",
    color: "white",
  },
  startRecordingView: {
    position: "absolute",
    zIndex: 400,
    width: "100%",
    height: "80%",
    top: "10%",
    justifyContent: "center",
  },
  startRecordingSubView: {
    width: "40%",
    height: "50%",
    alignSelf: "center",
    borderRadius: 10,
    justifyContent: "space-evenly",
    backgroundColor: "#FFFFFF",
    paddingHorizontal: 16,
    elevation: 4,
  },
  textTitle: {
    color: "#000000",
    fontSize: 18,
    fontFamily: "Muli-Regular",
    alignSelf: "center",
    // paddingBottom: 24,
  },
  // startRecordingButton: {
  //   width: "70%",
  //   height: "10%",
  //   alignSelf: "center",
  // },
});
export default DemoVideo;
